Learn R Programming

VisCov (version 1.5.0)

panelSelectCorr: Selecting a Panel(s) using the Mouse

Description

To visualize relevant parameters for correlation matrix, removing those panels related to variances.

Usage

panelSelectCorr(CovPlotData, range.logical.contour = FALSE,
                range.logical.all = TRUE)

Value

No return value, called for side effects.

Arguments

CovPlotData

the output list returned by VisCov.

range.logical.all

a logical value indicating whether the ranges in the panels are set as the same over different sets of samples. For the histograms, the ranges of frequencies are set as the same over the different sets of samples.

range.logical.contour

a logical value indicating whether the ranges of the contour plots are set as the same over different sets of samples when range.logical.all is TRUE.

Details

After drawing a graph by VisCov, one can select and draw relevant panels for correlation matrix.

References

Tokuda, T., Goodrich, B., Van Mechelen, I., Gelman, A. and Tuerlinckx, F. (submitted). Visualizing Distributions of Covariance Matrices.

Examples

Run this code
# \donttest{
set.seed(1234)
distribution = "LKJ"
eta = 5
dim = 50
param = list(prob = 0.5, dim = dim, eta=eta, scaleCov = diag(1,dim))
CovPlotData = VisCov(distribution, param,title.logical = FALSE)
panelSelectCorr(CovPlotData)
# }

Run the code above in your browser using DataLab